@@ -4,7 +4,7 @@ use serde::{Deserialize, Serialize};
 use cosmwasm_std::{to_binary, Addr, CosmosMsg, StdResult, WasmMsg};
 
 use crate::msg::{Cw3ExecuteMsg, Vote};
-use cw0::Expiration;
+use cw_utils::Expiration;
 
 /// Cw3Contract is a wrapper around Addr that provides a lot of helpers
 /// for working with this.
@@ -25,7 +25,7 @@ impl Cw3Contract {
         Ok(WasmMsg::Execute {
             contract_addr: self.addr().into(),
             msg: to_binary(&msg)?,
-            send: vec![],
+            funds: vec![],
         }
         .into())
     }
